@@ -8,6 +8,7 @@
 class QWebView;
 class QVBoxLayout;
 class LatitudeSettings;
+class QLabel;
 
 #ifndef Q_WS_MAEMO_5
     class QPushButton;
@@ -23,18 +24,22 @@ public slots:
     void setPosition(const QtMobility::QGeoPositionInfo &pos);
     void settingsDone();
     void test();
+    void showSettings();
 
 signals:
 
-public slots:
-
-    void showSettings();
+private slots:
+    void replyFinished(QNetworkReply*);
 
 private:
-    QWebView *m_webView;
+    //QWebView *m_webView;
+    QLabel *m_address;
+
+    QNetworkAccessManager *m_networkManager;
+
     QVBoxLayout *m_layout;
 
-    QString m_html;
+    //QString m_html;
 
     Latitude latitude;
     LatitudeSettings *m_settingsDialog;
